
# How to contribute

Thanks for getting involved in Penman's development!

### Reporting bugs and requesting features

Please report bugs or feature requests on the
[issues](https://github.com/goodmami/penman/issues) page.
Mention the version numbers of Penman and Python that you are using.
Also report inaccurate or missing documentation from the
[API docs](https://penman.readthedocs.io/).

### Contributing code

If you wish to contribute code to Penman, please fork the repository to
your own account, commit your changes, and submit a
[pull request](https://github.com/goodmami/penman/compare/) to the
`main` branch.

Please follow [PEP8](python.org/dev/peps/pep-0008/) unless you have a
good reason not to, and also try to follow the conventions set by the
Penman codebase.

I use the [GitHub Flow][] branching model. Basically, each new
changeset (e.g. features or bug fixes) should have its own
branch. When a branch is ready it gets merged to the `main` branch
and a new release is made.

[GitHub Flow]: https://guides.github.com/introduction/flow/
